# webauthn-client

Javascript client for plugins to authenticate with WebAuthn against privacyIDEA

This is a client-side library, that can be used to facilitate authentication
against privacyIDEA using WebAuthn tokens. For an example on how to build an
authentication flow using this library, please see
[privacyidea/webauthn-demo](https://github.com/privacyidea/webauthn-demo).